===============================
StoneRedis
===============================

.. image:: https://img.shields.io/pypi/v/stoneredis.svg
        :target: https://pypi.python.org/pypi/stoneredis

.. image:: https://img.shields.io/travis/stoneworksolutions/stoneredis.svg
        :target: https://travis-ci.org/stoneworksolutions/stoneredis

.. image:: https://readthedocs.org/projects/stoneredis/badge/?version=latest
        :target: https://readthedocs.org/projects/stoneredis/?badge=latest
        :alt: Documentation Status


Redis client based on redis-py client with some added features

* Free software: ISC license
* Documentation: https://stoneredis.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
